==> zio-aws-ec2_2.12-5.17.103.1-sources.jar: zio/aws/ec2/model/CreateTransitGatewayConnectRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.TransitGatewayAttachmentId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateTransitGatewayConnectRequest(
    transportTransitGatewayAttachmentId: TransitGatewayAttachmentId,
    options: zio.aws.ec2.model.CreateTransitGatewayConnectRequestOptions,
    tagSpecifications: Option[Iterable[zio.aws.ec2.model.TagSpecification]] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectRequest = {
    import CreateTransitGatewayConnectRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectRequest
      .builder()
      .transportTransitGatewayAttachmentId(
        TransitGatewayAttachmentId.unwrap(
          transportTransitGatewayAttachmentId
        ): java.lang.String
      )
      .options(options.buildAwsValue())
      .optionallyWith(
        tagSpecifications.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tagSpecifications)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CreateTransitGatewayConnectRequest.ReadOnly =
    zio.aws.ec2.model.CreateTransitGatewayConnectRequest.wrap(buildAwsValue())
}
object CreateTransitGatewayConnectRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateTransitGatewayConnectRequest =
      zio.aws.ec2.model.CreateTransitGatewayConnectRequest(
        transportTransitGatewayAttachmentId,
        options.asEditable,
        tagSpecifications.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def transportTransitGatewayAttachmentId: TransitGatewayAttachmentId
    def options
        : zio.aws.ec2.model.CreateTransitGatewayConnectRequestOptions.ReadOnly
    def tagSpecifications
        : Option[List[zio.aws.ec2.model.TagSpecification.ReadOnly]]
    def getTransportTransitGatewayAttachmentId
        : ZIO[Any, Nothing, TransitGatewayAttachmentId] =
      ZIO.succeed(transportTransitGatewayAttachmentId)
    def getOptions: ZIO[
      Any,
      Nothing,
      zio.aws.ec2.model.CreateTransitGatewayConnectRequestOptions.ReadOnly
    ] = ZIO.succeed(options)
    def getTagSpecifications: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.TagSpecification.ReadOnly
    ]] = AwsError.unwrapOptionField("tagSpecifications", tagSpecifications)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectRequest
  ) extends zio.aws.ec2.model.CreateTransitGatewayConnectRequest.ReadOnly {
    override val transportTransitGatewayAttachmentId
        : TransitGatewayAttachmentId = zio.aws.ec2.model.primitives
      .TransitGatewayAttachmentId(impl.transportTransitGatewayAttachmentId())
    override val options
        : zio.aws.ec2.model.CreateTransitGatewayConnectRequestOptions.ReadOnly =
      zio.aws.ec2.model.CreateTransitGatewayConnectRequestOptions
        .wrap(impl.options())
    override val tagSpecifications
        : Option[List[zio.aws.ec2.model.TagSpecification.ReadOnly]] = scala
      .Option(impl.tagSpecifications())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.TagSpecification.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectRequest
  ): zio.aws.ec2.model.CreateTransitGatewayConnectRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.11-sources.jar: zio/aws/ec2/model/CreateTransitGatewayConnectRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.TransitGatewayAttachmentId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateTransitGatewayConnectRequest(
    transportTransitGatewayAttachmentId: TransitGatewayAttachmentId,
    options: zio.aws.ec2.model.CreateTransitGatewayConnectRequestOptions,
    tagSpecifications: Optional[Iterable[zio.aws.ec2.model.TagSpecification]] =
      Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectRequest = {
    import CreateTransitGatewayConnectRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectRequest
      .builder()
      .transportTransitGatewayAttachmentId(
        TransitGatewayAttachmentId.unwrap(
          transportTransitGatewayAttachmentId
        ): java.lang.String
      )
      .options(options.buildAwsValue())
      .optionallyWith(
        tagSpecifications.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tagSpecifications)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CreateTransitGatewayConnectRequest.ReadOnly =
    zio.aws.ec2.model.CreateTransitGatewayConnectRequest.wrap(buildAwsValue())
}
object CreateTransitGatewayConnectRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateTransitGatewayConnectRequest =
      zio.aws.ec2.model.CreateTransitGatewayConnectRequest(
        transportTransitGatewayAttachmentId,
        options.asEditable,
        tagSpecifications.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        dryRun.map(value => value)
      )
    def transportTransitGatewayAttachmentId: TransitGatewayAttachmentId
    def options
        : zio.aws.ec2.model.CreateTransitGatewayConnectRequestOptions.ReadOnly
    def tagSpecifications
        : Optional[List[zio.aws.ec2.model.TagSpecification.ReadOnly]]
    def dryRun: Optional[Boolean]
    def getTransportTransitGatewayAttachmentId
        : ZIO[Any, Nothing, TransitGatewayAttachmentId] =
      ZIO.succeed(transportTransitGatewayAttachmentId)
    def getOptions: ZIO[
      Any,
      Nothing,
      zio.aws.ec2.model.CreateTransitGatewayConnectRequestOptions.ReadOnly
    ] = ZIO.succeed(options)
    def getTagSpecifications: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.TagSpecification.ReadOnly
    ]] = AwsError.unwrapOptionField("tagSpecifications", tagSpecifications)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectRequest
  ) extends zio.aws.ec2.model.CreateTransitGatewayConnectRequest.ReadOnly {
    override val transportTransitGatewayAttachmentId
        : TransitGatewayAttachmentId = zio.aws.ec2.model.primitives
      .TransitGatewayAttachmentId(impl.transportTransitGatewayAttachmentId())
    override val options
        : zio.aws.ec2.model.CreateTransitGatewayConnectRequestOptions.ReadOnly =
      zio.aws.ec2.model.CreateTransitGatewayConnectRequestOptions
        .wrap(impl.options())
    override val tagSpecifications
        : Optional[List[zio.aws.ec2.model.TagSpecification.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tagSpecifications())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.TagSpecification.wrap(item)
          }.toList
        )
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectRequest
  ): zio.aws.ec2.model.CreateTransitGatewayConnectRequest.ReadOnly =
    new Wrapper(impl)
}
